@@ -13,11 +13,6 @@ PLUG_OFF_KEY = "570f50010100"
 class SwitchbotPlugMini(SwitchbotDevice):
     """Representation of a Switchbot plug mini."""
 
-    def __init__(self, *args: Any, **kwargs: Any) -> None:
-        """Switchbot plug mini constructor."""
-        super().__init__(*args, **kwargs)
-        self._settings: dict[str, Any] = {}
-
     async def update(self, interface: int | None = None) -> None:
         """Update state of device."""
         await self.get_device_data(retry=self._retry_count, interface=interface)
@@ -35,7 +30,4 @@ class SwitchbotPlugMini(SwitchbotDevice):
     def is_on(self) -> Any:
         """Return switch state from cache."""
         # To get actual position call update() first.
-        value = self._get_adv_value("isOn")
-        if value is None:
-            return None
-        return value
+        return self._get_adv_value("isOn")
